API reference
=============

Event
-----

.. autoclass:: rnnr.Event

Runner
------

.. autoclass:: rnnr.Runner
   :members:

.. _Handlers:

Handlers
--------

.. autoclass:: rnnr.handlers.EarlyStopper

.. autoclass:: rnnr.handlers.Checkpointer

.. _Attachments:

Attachments
-----------

.. autoclass:: rnnr.attachments.Attachment
   :members:
   :show-inheritance:

.. autoclass:: rnnr.attachments.ProgressBar
   :show-inheritance:

.. autoclass:: rnnr.attachments.MeanAggregator
   :show-inheritance:
